@@ -19,8 +19,8 @@
 **/
 
 /*
-** $Date:: 2016-02-22 10:27:07 +0900 #$
-** $Revision: 6998 $
+** $Date:: 2017-07-31 13:25:49 +0900 #$
+** $Revision: 7261 $
 ** $Author: sypark@FITECHLABS.CO.JP $
 **/
 
@@ -147,6 +147,7 @@ int	ja_log(char *message_id, zbx_uint64_t inner_jobnet_id, char *jobnet_id, zbx_
 	char		jobnet_name[JA_JOBNET_NAME_LEN] = "";
 	char		job_name[JA_JOB_NAME_LEN] = "";
 	char		now_time[20];
+	char		*str_inner_jobnet_main_id;
 	const char	*__function_name = "ja_log";
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() message_id: %s inner_jobnet_id: " ZBX_FS_UI64 " inner_job_id: " ZBX_FS_UI64,
@@ -585,10 +586,14 @@ int	ja_log(char *message_id, zbx_uint64_t inner_jobnet_id, char *jobnet_id, zbx_
 				continue;
 			}
 			/* start command in the background */
-			zbx_snprintf(cmd, sizeof(cmd), "%s/%s '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' &",
-				CONFIG_ERROR_CMD_PATH, dp->d_name, s_user_name, s_jobnet_id, now_date, message_id, type, message, host_name, s_job_id_full);
+
+			str_inner_jobnet_main_id = NULL;
+			str_inner_jobnet_main_id = zbx_dsprintf(NULL,"" ZBX_FS_UI64 "" ,inner_jobnet_main_id);
+			zbx_snprintf(cmd, sizeof(cmd), "%s/%s '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' &",
+				CONFIG_ERROR_CMD_PATH, dp->d_name, s_user_name, s_jobnet_id, now_date, message_id, type, message, host_name, s_job_id_full,str_inner_jobnet_main_id);
 			rc = system(cmd);
 			zabbix_log(LOG_LEVEL_DEBUG, "application execution [%s] (%d)", cmd, rc);
+			zbx_free(str_inner_jobnet_main_id);
 			if (rc != EXIT_SUCCESS)
 			{
 				if (WIFEXITED(rc))
