@@ -19,8 +19,8 @@
 **/
 
 /*
-** $Date:: 2016-03-23 17:32:59 +0900 #$
-** $Revision: 7031 $
+** $Date:: 2019-09-04 13:19:26 +0900 #$
+** $Revision: 7480 $
 ** $Author: sypark@FITECHLABS.CO.JP $
 **/
 
@@ -221,41 +221,46 @@ int ja_set_value_after(const zbx_uint64_t inner_job_id,
     if (after_value == NULL) {
         after_value_esc = DBdyn_escape_string("");
     } else {
-        after_value_esc = DBdyn_escape_string(after_value);
 
-        char dst[JA_STD_OUT_LEN];
-        char n1 = 0, n2 = 0;
-        int i = 0, j = 0, k = 0;
+        char dst[JA_STD_OUT_LEN+1];
+        int i = 0, j = 0;
 
-        for(i=0; i<strlen(after_value_esc); i++) {
-        	if ((after_value_esc[i] & 0x80) == 0){
-        		dst[j++] = after_value_esc[i];
-        		k = 0;
-        	}else if ((after_value_esc[i] & 0xf0) == 0xe0){
-        		n1 = after_value_esc[i];
-        		k = 1;
-        	}else if (((after_value_esc[i] & 0xc0) == 0x80)
-        			&& ( 0 < k && k < 7)){
-        		if ( n1 != 0  && n2 == 0 ){
-        			n2 = after_value_esc[i];
-        			++k;
-        		}else{
-        			if(n1 != 0 ){
-        				dst[j++] = n1;
-        			}
-        			if(n2 != 0 ){
-        				dst[j++] = n2;
-        			}
-        			dst[j++] = after_value_esc[i];
-        			n1 = n2 = 0;
-        			++k;
+        i = strlen(after_value);
+
+        zabbix_log(LOG_LEVEL_DEBUG,"In %s()  data length [%d] after_value [%s] ",__function_name,i,after_value);
+
+        if(i >=  JA_STD_OUT_LEN -1 ){
+        	for(i = JA_STD_OUT_LEN - 1 ; i> 0; i--){
+        		if(after_value[i] == NULL){
+        			zabbix_log(LOG_LEVEL_DEBUG,"1byte NULL 0x[%x] [%d] ",after_value[i],i);
+        			continue;
         		}
+        		if((after_value[i] & 0xf0) == 0xf0){ // 4バイト文字
+					zabbix_log(LOG_LEVEL_DEBUG,"4byte 0xf0 [%d] ",i);
+        	    	break;
+				}else if((after_value[i] & 0xe0) == 0xe0){ // 3バイト文字
+					zabbix_log(LOG_LEVEL_DEBUG,"3byte 0xe0 [%d] ",i);
+					break;
+				}else if((after_value[i] & 0xc0) == 0xc0){ // 2バイト文字
+					zabbix_log(LOG_LEVEL_DEBUG,"2-1byte 0xc0 [%d] ",i);
+					break;
+				}else if((after_value[i] & 0x80) == 0){ // 1バイト文字の場合
+        			zabbix_log(LOG_LEVEL_DEBUG,"1byte 0x[%x] [%d] ",after_value[i],i);
+					break;
+				}
+        	}
+        	for(j = 0; j < i; j++){
+        		dst[j] = after_value[j];
+        	}
 
-        	}else
-        		k = 0;
+  	        dst[j] = '\0';
+   	        zabbix_log(LOG_LEVEL_DEBUG,"In %s() strlen [%d] i=[%d] j=[%d]\n",__function_name, strlen(dst),i,j+1);
+   	        after_value_esc = DBdyn_escape_string(dst);
+
+        }else{
+        	after_value_esc = DBdyn_escape_string(after_value);
         }
-        dst[j] = '\0';
-        after_value_esc = zbx_dsprintf(NULL,"%s",dst);
+
     }
 
     db_ret =
@@ -273,6 +278,7 @@ int ja_set_value_after(const zbx_uint64_t inner_job_id,
 
     zbx_free(value_name_esc);
     zbx_free(after_value_esc);
+
     return ret;
 }
 
