@@ -19,9 +19,9 @@
 **/
 
 /*
-** $Date:: 2014-11-11 13:25:08 +0900 #$
-** $Revision: 6642 $
-** $Author: nagata@FITECHLABS.CO.JP $
+** $Date:: 2020-06-08 13:18:57 +0900 #$
+** $Revision: 7518 $
+** $Author: matsubara@FITECHLABS.CO.JP $
 **/
 
 #include "common.h"
@@ -43,6 +43,7 @@
 #include "listener.h"
 #include "executive.h"
 #include "jobarg_agentd.h"
+#include "jadbbackup.h"
 
 /******************************************************************************
  *                                                                            *
@@ -248,11 +249,11 @@ static void set_defaults()
 
 #ifdef USE_PID_FILE
     if (NULL == CONFIG_PID_FILE)
-        CONFIG_PID_FILE = "/tmp/jobarg_agentd.pid";
+        CONFIG_PID_FILE = "/var/lib/jobarranger/tmp/jobarg_agentd.pid";
 #endif
 
     if (NULL == CONFIG_TMPDIR)
-        CONFIG_TMPDIR = zbx_strdup(CONFIG_TMPDIR, "/tmp");
+        CONFIG_TMPDIR = zbx_strdup(CONFIG_TMPDIR, "/var/lib/jobarranger/tmp");
 }
 
 /******************************************************************************
@@ -291,6 +292,7 @@ static void jobarg_load_config(int requirement)
         {"JaDatabaseFile",    &CONFIG_DATABASE_FILE,       TYPE_STRING, PARM_MAND, 0,   0},
         {"JaJobHistory",      &CONFIG_JOB_HISTORY,         TYPE_INT,    PARM_OPT,  1,   365},
         {"JaBackupTime",      &CONFIG_BACKUP_TIME,         TYPE_INT,    PARM_OPT,  1,   24},
+        {"JaBackupRunTime",      &CONFIG_BACKUP_RUN_TIME,  TYPE_INT,    PARM_OPT,  0,   24},
         {"JaExtjobPath",      &CONFIG_EXTJOB_PATH,         TYPE_STRING, PARM_MAND, 0,   0},
         {"JaFcopyTimeout",    &CONFIG_FCOPY_TIMEOUT,       TYPE_INT,    PARM_OPT,  1,   3600},
         {"JaListenRetry",     &CONFIG_LISTEN_RETRY,        TYPE_INT,    PARM_OPT,  0,   3600},
@@ -443,7 +445,7 @@ int MAIN_ZABBIX_ENTRY()
     }
 
     /* --- START THREADS --- */
-    threads_num = 2;
+    threads_num = 3;
     threads =
         (ZBX_THREAD_HANDLE *) zbx_calloc(threads, threads_num,
                                          sizeof(ZBX_THREAD_HANDLE));
@@ -463,6 +465,13 @@ int MAIN_ZABBIX_ENTRY()
     thread_args->args = &listen_sock;
     threads[thread_num++] = zbx_thread_start(listener_thread, thread_args);
 
+    /* start the jadbbackup thread */
+    thread_args =
+        (zbx_thread_args_t *) zbx_malloc(NULL, sizeof(zbx_thread_args_t));
+    thread_args->thread_num = thread_num;
+    thread_args->args = NULL;
+    threads[thread_num++] = zbx_thread_start(jadbbackup_thread, thread_args);
+
 #ifdef _WINDOWS
     set_parent_signal_handler();
     res =
