@@ -347,7 +347,7 @@ static int    message_send(ja_zbxsnd_info_t *zbxsnd)
     struct tm    *tm, stm;
     time_t       now;
     int          send_status, retry_count, message_type, rc, state;
-    char         *user_name, *jobnet_id, *jobnet_name, *job_id, *job_id_full, *job_name, *log_message_id, *log_message;
+    char         *user_name, *jobnet_id, *jobnet_name, *job_id, *job_id_full, *job_name, *log_message_id, *log_message, *inner_jobnet_main_id;
     char         yy[5], mm[3], dd[3], hh[3], mi[3], ss[3];
     char         now_date[DATE_LEN], now_time[80], retry_date[DATE_LEN], msg_type[10], cmd[JA_MAX_DATA_LEN * 2], host_name[JA_MAX_DATA_LEN];
     const char   *__function_name = "message_send";
@@ -360,7 +360,7 @@ static int    message_send(ja_zbxsnd_info_t *zbxsnd)
 
     result = DBselect("select send_no, message_date, send_status, retry_count, retry_date,"
                       " message_type, user_name, host_name, jobnet_id, jobnet_name, job_id,"
-                      " job_id_full, job_name, log_message_id, log_message"
+                      " job_id_full, job_name, log_message_id, log_message, inner_jobnet_main_id"
                       " from ja_send_message_table"
                       " where (send_status = %d or send_status = %d) and retry_date <= %s"
                       " order by retry_date, message_date",
@@ -380,6 +380,7 @@ static int    message_send(ja_zbxsnd_info_t *zbxsnd)
         job_name        = "";
         log_message_id  = "";
         log_message     = "";
+        inner_jobnet_main_id = "";
 
         zbx_strlcpy(yy,  row[1],       sizeof(yy));
         zbx_strlcpy(mm, (row[1] + 4),  sizeof(mm));
@@ -472,10 +473,13 @@ static int    message_send(ja_zbxsnd_info_t *zbxsnd)
         if (SUCCEED != DBis_null(row[14])) {
             log_message = row[14];
         }
+        if (SUCCEED != DBis_null(row[15])) {
+        	inner_jobnet_main_id = row[15];
+                }
 
-        zbx_snprintf(cmd, sizeof(cmd), "%s -z '%s' -p '%s' -s '%s' -k '%s' -o '[%s] [%s] [%s] %s (USER NAME=%s %s JOBNET=%s JOB=%s)'",
+        zbx_snprintf(cmd, sizeof(cmd), "%s -z '%s' -p '%s' -s '%s' -k '%s' -o '[%s] [%s] [%s] %s (USER NAME=%s %s JOBNET=%s JOB=%s INNER_JOBNET_MAIN_ID=%s)'",
                      zbxsnd->sender, zbxsnd->zabbix_ip, zbxsnd->zabbix_port, zbxsnd->zabbix_host, zbxsnd->item_key,
-                     now_time, msg_type, log_message_id, log_message, user_name, host_name, jobnet_id, job_id_full);
+                     now_time, msg_type, log_message_id, log_message, user_name, host_name, jobnet_id, job_id_full, inner_jobnet_main_id);
 
         /* command execution */
         state = system(cmd);
