@@ -88,7 +88,7 @@ char *CONFIG_DBSOCKET        = NULL;
 int  CONFIG_DBPORT           = 0;
 
 int  CONFIG_AGENT_LISTEN_PORT    = JA_DEFAULT_AGENT_PORT;
-int  CONFIG_ZABBIX_VERSION       = 1;
+int  CONFIG_ZABBIX_VERSION       = 3;
 char *CONFIG_JA_LOG_MESSAGE_FILE = NULL;
 char *CONFIG_ERROR_CMD_PATH      = NULL;
 
@@ -1290,7 +1290,7 @@ static int get_agentless_info(const zbx_uint64_t inner_job_id)
             				 if (j == strlen(key)) j =0;
    		 				}
             		 }
-
+            		 dec[k]='\0';
             		 searchChar = strchr(dec,'|');
             		 if ( searchChar == NULL )
             			 zbx_strlcpy(passwd, d_passwd, sizeof(passwd));
@@ -1307,6 +1307,9 @@ static int get_agentless_info(const zbx_uint64_t inner_job_id)
             	 			     break;
             	 			 }
             	 		 }
+            	 		zabbix_log(LOG_LEVEL_DEBUG,"Change dec[%s]: , searchChar:[%s] strlen(dec)=[%d] strlen(searchChar)=[%d] lenth[%d]",
+            	 				dec, searchChar,  strlen(dec) ,strlen(searchChar) ,splitLen);
+
             	 		 if( i != 0){
             	 			 if ( atoi(d_num) == (strlen(searchChar)-1)) {
             	 				 for(i=0; i < atoi(d_num) ;i++ ){
